# Views AI Summary

## Overview

The Views AI Summary module extends the AI Module’s ecosystem by providing a
powerful tool that integrates seamlessly with Drupal Views. This module
leverages AI to summarize view results, offering a flexible and intelligent
way to display content summaries directly within your Drupal site.

## Features

- **Integration with AI Module**: Fully compatible with the AI Module, allowing
  you to use various LLM engines supported by it.
- **Dynamic Content Summarization**: Automatically summarizes the first
  1-5 results of a View, including excluded fields if required.
- **Customizable Display**:
  - Deploy the summary block alongside view results.
  - Optionally, expose only the summary block, hiding the actual view results
    for a concise display.
- **User-Friendly Configuration**:
  - Choose the number of rows to summarize.
  - Select which View fields should be processed by the AI.
  - Pick your preferred LLM engine (requires at least one enabled LLM provider
    from the AI module). E.g. OpenAI's gpt-3.5-turbo works well.
  - Define the maximum number of tokens the AI can process.
- **AJAX Loading**: The AI Summary is loaded with AJAX, which doesn't slow down
  the loading of the search results.

## Drush AI command

This module comes with `drush vais:ai-summary-field` command, enabling you to
batch-create summaries for selected text fields. These summaries can be used
in View results or as a base for the summary of the View output.

## Usage Instructions

1. Enable the Views AI Summary module as you would with any other Drupal module.
2. Navigate to the Blocks layout page, place the Views AI Summary block, and
   limit its access to a page (pages) that is (are) a View(s). The block will
   gracefully display a ‘no View’ message if placed on a non-View page.
3. Configure the Block:
   - Select the number of rows (1-5) to be summarized.
   - Choose which View fields should be processed by the LLM.
   - Select your preferred LLM engine from those enabled in the AI module.
   - Set the token limit for the LLM to process.
   - Set placeholder text and animation.
4. Save your block settings.

## Requirements

- Drupal 10.3 and higher
- [AI module](https://www.drupal.org/project/ai)

## Installation

1. Install via Composer.
2. Enable the module through the Drupal administration interface or via Drush
   (`drush en vais`).

## Support & Maintenance

For any issues or feature requests,
please use the [issue tracker](https://www.drupal.org/project/issues/vais) on
the project page.

## Maintainer

Michal Gow (seogow) - https://www.drupal.org/u/seogow
