<?php

namespace Drupal\vais\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\vais\Utility\VaisLlmUtility;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for LLM callback.
 */
class VaisController extends ControllerBase {

  /**
   * Convert Markup into HTML.
   *
   * @var \Parsedown
   */
  protected \Parsedown $parseDown;

  /**
   * Constructs a new VaisController instance.
   *
   * @param \Drupal\vais\Utility\VaisLlmUtility $llmUtility
   *   Create new scratch file from selection.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   */
  public function __construct(
    protected VaisLlmUtility $llmUtility,
    protected LoggerInterface $logger
  ) {
    $this->parseDown = new \Parsedown();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('vais.llm_utility'),
      $container->get('logger.factory')->get('vais')
    );
  }

  /**
   * Provides summary of text in POST data.
   */
  public function ajaxSummary(Request $request) {

    // Ensure only allowed users can access llm.
    $current_user = $this->currentUser();
    if (!$current_user->hasPermission('access summary vais')) {
      $this->logger->warning('User @uid (@username) does not have permission to access the summary.', [
        '@uid' => $current_user->id(),
        '@username' => $current_user->getAccountName(),
      ]);
      return new JsonResponse(['summary' => 'Access denied.']);
    }

    // Return summary.
    $summary = $this->generateSummary($request);
    return new JsonResponse(['summary' => $summary]);
  }

  /**
   * Summarization call to LLM.
   */
  private function generateSummary($request) {
    try {
      $output = $this->llmUtility->getResponse(
        $request->get('prompt'),
        $request->get('llm'),
      );
      return $this->parseDown->text($output);
    }
    catch (\Exception $e) {
      $this->logger->error('Error in VaisViewBlock: @message', ['@message' => $e->getMessage()]);
      return "Something went wrong.";
    }
  }

}
